package com.bonus.canteen.core.supermarket.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.supermarket.domain.SupermarketUnit;
import com.bonus.canteen.core.supermarket.service.ISupermarketUnitService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 计量单位Controller
 * 
 * @author xsheng
 * @date 2025-05-15
 */
@Api(tags = "计量单位接口")
@RestController
@RequestMapping("/supermarket_unit")
public class SupermarketUnitController extends BaseController {
    @Autowired
    private ISupermarketUnitService supermarketUnitService;

    /**
     * 查询计量单位列表
     */
    @ApiOperation(value = "查询计量单位列表")
    //@RequiresPermissions("supermarket:unit:list")
    @GetMapping("/list")
    public TableDataInfo list(SupermarketUnit supermarketUnit) {
        startPage();
        List<SupermarketUnit> list = supermarketUnitService.selectSupermarketUnitList(supermarketUnit);
        return getDataTable(list);
    }

    /**
     * 导出计量单位列表
     */
    @ApiOperation(value = "导出计量单位列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:unit:export")
    @SysLog(title = "计量单位", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出计量单位")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SupermarketUnit supermarketUnit) {
        List<SupermarketUnit> list = supermarketUnitService.selectSupermarketUnitList(supermarketUnit);
        ExcelUtil<SupermarketUnit> util = new ExcelUtil<SupermarketUnit>(SupermarketUnit.class);
        util.exportExcel(response, list, "计量单位数据");
    }

    /**
     * 获取计量单位详细信息
     */
    @ApiOperation(value = "获取计量单位详细信息")
    //@RequiresPermissions("supermarket:unit:query")
    @GetMapping(value = "/{unitId}")
    public AjaxResult getInfo(@PathVariable("unitId") Long unitId) {
        return success(supermarketUnitService.selectSupermarketUnitByUnitId(unitId));
    }

    /**
     * 新增计量单位
     */
    @ApiOperation(value = "新增计量单位")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:unit:add")
    @SysLog(title = "计量单位", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增计量单位")
    @PostMapping
    public AjaxResult add(@RequestBody SupermarketUnit supermarketUnit) {
        try {
            return toAjax(supermarketUnitService.insertSupermarketUnit(supermarketUnit));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改计量单位
     */
    @ApiOperation(value = "修改计量单位")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:unit:edit")
    @SysLog(title = "计量单位", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改计量单位")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody SupermarketUnit supermarketUnit) {
        try {
            return toAjax(supermarketUnitService.updateSupermarketUnit(supermarketUnit));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除计量单位
     */
    @ApiOperation(value = "删除计量单位")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:unit:remove")
    @SysLog(title = "计量单位", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除计量单位")
	@PostMapping("/del/{unitIds}")
    public AjaxResult remove(@PathVariable Long[] unitIds) {
        return toAjax(supermarketUnitService.deleteSupermarketUnitByUnitIds(unitIds));
    }
}
